@@ -1,5 +1,5 @@
 @muladd function perform_step!(integrator, cache::SplitEMConstantCache)
-    @unpack t, dt, uprev, u, W, p, f = integrator
+    (; t, dt, uprev, u, W, p, f) = integrator
     u = dt*(integrator.f.f1(uprev, p, t) +
             integrator.f.f2(uprev, p, t)) +
         integrator.g(uprev, p, t) .* W.dW + uprev
@@ -7,8 +7,8 @@
 end
 
 @muladd function perform_step!(integrator, cache::SplitEMCache)
-    @unpack rtmp1, rtmp2 = cache
-    @unpack t, dt, uprev, u, W, p, f = integrator
+    (; rtmp1, rtmp2) = cache
+    (; t, dt, uprev, u, W, p, f) = integrator
 
     integrator.g(rtmp2, uprev, p, t)
     if is_diagonal_noise(integrator.sol.prob)
